showCusDialog method
Shows a dialog as an app dialog over the current page.
Implementation
void showCusDialog(Widget dialog) {
showDialog(context: this, builder: (BuildContext context) => dialog);
}
Shows a dialog as an app dialog over the current page.
void showCusDialog(Widget dialog) {
showDialog(context: this, builder: (BuildContext context) => dialog);
}