isToday method
Whether it is the same calendar day as today.
Implementation
bool isToday() {
final now = DateTime.now();
return year == now.year && month == now.month && day == now.day;
}
Whether it is the same calendar day as today.
bool isToday() {
final now = DateTime.now();
return year == now.year && month == now.month && day == now.day;
}