isAudio property
bool
get
isAudio
Whether the file extension is a common audio type.
Implementation
bool get isAudio =>
const ['mp3', 'wav', 'aac', 'flac', 'ogg', 'm4a'].contains(_ext);
Whether the file extension is a common audio type.
bool get isAudio =>
const ['mp3', 'wav', 'aac', 'flac', 'ogg', 'm4a'].contains(_ext);