isVideo property
bool
get
isVideo
Whether the file extension is a common video type.
Implementation
bool get isVideo =>
const ['mp4', 'mkv', 'avi', 'mov', 'webm', 'm4v'].contains(_ext);
Whether the file extension is a common video type.
bool get isVideo =>
const ['mp4', 'mkv', 'avi', 'mov', 'webm', 'm4v'].contains(_ext);