extensions/file_stub library
Stub used on platforms without dart:io (the web).
The File extensions are intentionally unavailable here because they
depend on dart:io.
Stub used on platforms without dart:io (the web).
The File extensions are intentionally unavailable here because they
depend on dart:io.