currentRouteName property
String?
get
currentRouteName
Name of the current route, or null if unnamed.
Implementation
String? get currentRouteName => ModalRoute.of(this)?.settings.name;
Name of the current route, or null if unnamed.
String? get currentRouteName => ModalRoute.of(this)?.settings.name;