let<R> method
R
let<R>(
- R block(
- T
Calls block with this as argument and returns the result.
Implementation
R let<R>(R Function(T) block) => block(this);
Calls block with this as argument and returns the result.
R let<R>(R Function(T) block) => block(this);