run<R> method
R
run<R>(
- R block(
- T
Runs block with this and returns the result (alias of let).
Implementation
R run<R>(R Function(T) block) => block(this);
Runs block with this and returns the result (alias of let).
R run<R>(R Function(T) block) => block(this);