PlatformInfo class
Flags for the platform the app is actually running on.
Constructors
- PlatformInfo({required bool isAndroid, required bool isMacOS, required bool isWindows, required bool isFuchsia, required bool isWeb, required bool isIOS, required bool isLinux})
-
Creates a PlatformInfo with the given flags.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAndroid → bool
-
Indicates wheter the platform is android
final
- isFuchsia → bool
-
Indicates wheter the platform is fuchsia
final
- isIOS → bool
-
Indicates wheter the platform is ios
final
- isLinux → bool
-
Indicates wheter the platform is linux
final
- isMacOS → bool
-
Indicates wheter the platform is macOS
final
- isWeb → bool
-
Indicates wheter the platform is web
final
- isWindows → bool
-
Indicates wheter the platform is windows
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited