TargetPlatformInfo class
Flags for the TargetPlatform resolved from the widget tree theme.
Constructors
- TargetPlatformInfo({required bool isAndroid, required bool isFuchsia, required bool isIOS, required bool isLinux, required bool isMacOS, required bool isWindows})
-
Creates a TargetPlatformInfo with the given flags.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAndroid → bool
-
Indicates wheter the target platform is android
final
- isFuchsia → bool
-
Indicates wheter the target platform is fuchsia
final
- isIOS → bool
-
Indicates wheter the target platform is iOS
final
- isLinux → bool
-
Indicates wheter the target platform is linux
final
- isMacOS → bool
-
Indicates wheter the target platform is macOS
final
- isWindows → bool
-
Indicates wheter the target platform is windows
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited