isWeb top-level property
bool
get
isWeb
Whether the app is running in a browser (always false here).
Implementation
bool get isWeb => kIsWeb;
Whether the app is running in a browser (always false here).
bool get isWeb => kIsWeb;