isWeb top-level property
bool
get
isWeb
Whether the app is running in a browser (always true here).
Implementation
bool get isWeb => true;
Whether the app is running in a browser (always true here).
bool get isWeb => true;